==> de-2.9.1.zip: de/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Zum Inhalt';
$GLOBALS['__l10n']['To menu'] = 'Zum Menü';
$GLOBALS['__l10n']['To search'] = 'Zur Suche';
$GLOBALS['__l10n']['By'] = 'Von';
$GLOBALS['__l10n']['by'] = 'von';
$GLOBALS['__l10n']['on'] = 'am';
$GLOBALS['__l10n']['On'] = 'Am';
$GLOBALS['__l10n']['Continue reading'] = 'Weiterlesen';
$GLOBALS['__l10n']['no comments'] = 'Kein Kommentar';
$GLOBALS['__l10n']['one comment'] = 'Ein Kommentar';
$GLOBALS['__l10n']['%d comments'] = '%d Kommentare';
$GLOBALS['__l10n']['no trackbacks'] = 'Kein Trackback';
$GLOBALS['__l10n']['one trackback'] = 'Ein Trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d Trackbacks';
$GLOBALS['__l10n']['no attachments'] = 'Keine Dateianlage';
$GLOBALS['__l10n']['one attachment'] = 'Eine Dateianlage';
$GLOBALS['__l10n']['%d attachments'] = '%d Dateianlagen';
$GLOBALS['__l10n']['previous entries'] = 'ältere Einträge';
$GLOBALS['__l10n']['page'] = 'Seite';
$GLOBALS['__l10n']['of'] = 'von';
$GLOBALS['__l10n']['next entries'] = 'neure Einträge';
$GLOBALS['__l10n']['Search'] = 'Suche';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Deine Suche nach <em>%1$s</em> ergab keinen Treffer.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Deine Suche nach <em>%1$s</em> ergab <strong>%2$s</strong> Treffer.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Deine Suche nach <em>%1$s</em> ergab <strong>%2$s</strong> Treffer.';
$GLOBALS['__l10n']['Home'] = 'Startseite';
$GLOBALS['__l10n']['All keywords'] = 'Alle Schlüsselwörter';
$GLOBALS['__l10n']['Best of me'] = 'Das Wichtigste über mich';
$GLOBALS['__l10n']['Languages'] = 'Sprachen';
$GLOBALS['__l10n']['Categories'] = 'Kategorien';
$GLOBALS['__l10n']['Subcategories'] = 'Unterkategorien';
$GLOBALS['__l10n']['Archives'] = 'Archiv';
$GLOBALS['__l10n']['Links'] = 'Links';
$GLOBALS['__l10n']['Subscribe'] = 'Abonnements';
$GLOBALS['__l10n']['Entries feed'] = 'Feed für Einträge';
$GLOBALS['__l10n']['Comments feed'] = 'Feed für Kommentare';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Die Kommentare dieses Blogs als Atom-Feed abonnieren';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Die Einträge dieser Kategorie als Atom-Feed abonnieren';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Die Kommentare dieser Kategorie als Atom-Feed abonnieren';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Die Kommentare dieses Eintrags als Atom-Feed abonnieren';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Die Kommentare dieses Eintrags als Atom-Feed abonnieren';
$GLOBALS['__l10n']['Attachments'] = 'Dateianlagen';
$GLOBALS['__l10n']['Permalink'] = 'Permalink';
$GLOBALS['__l10n']['Comments'] = 'Kommentare';
$GLOBALS['__l10n']['Your comment'] = 'Dein Kommentar';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Dein Kommentar wurde erfolgreich veröffentlicht.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Dein Kommentar wurde gespeichert und wird nach Überprüfung veröffentlicht.';
$GLOBALS['__l10n']['Add a comment'] = 'Kommentar eintragen';
$GLOBALS['__l10n']['Name or nickname'] = 'Name oder Nickname';
$GLOBALS['__l10n']['Email address'] = 'E-Mail-Adresse';
$GLOBALS['__l10n']['Website'] = 'Website';
$GLOBALS['__l10n']['optional'] = 'freiwillig';
$GLOBALS['__l10n']['Comment'] = 'Kommentar';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = 'Kommentare können mit einfacher Wiki-Syntax formatiert werden.';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML-Code wird als normaler Text angezeigt, Links und Email-Adressen werden automatisch umgewandelt.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Speichere meine Angaben für diesen Blog';
$GLOBALS['__l10n']['preview'] = 'Vorschau';
$GLOBALS['__l10n']['send'] = 'Senden';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Folgende haben zum gleichen Thema veröffentlicht';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback-URL';
$GLOBALS['__l10n']['You must provide an author name'] = 'Du musst einen Namen oder Nicknamen angeben';
$GLOBALS['__l10n']['You must provide a comment'] = 'Du musst einen Kommentar eingeben';
$GLOBALS['__l10n']['Email address is not valid'] = 'Die E-Mail-Adresse ist nicht gültig';
$GLOBALS['__l10n']['Document not found'] = 'Dokument nicht gefunden';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Das gesuchte Dokument existiert nicht.';
$GLOBALS['__l10n']['Powered by %s'] = 'Erstellt mit %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Abonnieren von';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Was ist ein RSS-Feed?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '<abbr xml:lang="en" lang="en" title="Really Simple Syndication">RSS</abbr> ist eine kostenlose Inhaltsübersicht für den Blog. Man kann Inhalte (z.B. Einträge oder Kommentare) oder auch Auszüge von Inhalten mit Links und anderen Metadaten abonnieren. Diese kannst du dann in einem beliebigen <a href="http://de.wikipedia.org/wiki/Feedreader">Feedreader</a>. lesen.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Kopiere einfach den folgenden URL in deinen Feedreader:';
$GLOBALS['__l10n']['Password needed'] = 'Passwort erforderlich';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Für den Zutritt benötigst du ein Passwort.';
$GLOBALS['__l10n']['Password:'] = 'Passwort:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Du mußt eine gültige E-Mail-Adresse verwenden.';
$GLOBALS['__l10n']['Read'] = 'Lesen';

==> de-2.9.2.zip: de/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Zum Inhalt';
$GLOBALS['__l10n']['To menu'] = 'Zum Menü';
$GLOBALS['__l10n']['To search'] = 'Zur Suche';
$GLOBALS['__l10n']['By'] = 'Von';
$GLOBALS['__l10n']['by'] = 'von';
$GLOBALS['__l10n']['on'] = 'am';
$GLOBALS['__l10n']['On'] = 'Am';
$GLOBALS['__l10n']['Continue reading'] = 'Weiterlesen';
$GLOBALS['__l10n']['no comments'] = 'Kein Kommentar';
$GLOBALS['__l10n']['one comment'] = 'Ein Kommentar';
$GLOBALS['__l10n']['%d comments'] = '%d Kommentare';
$GLOBALS['__l10n']['no trackbacks'] = 'Kein Trackback';
$GLOBALS['__l10n']['one trackback'] = 'Ein Trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d Trackbacks';
$GLOBALS['__l10n']['no attachments'] = 'Keine Dateianlage';
$GLOBALS['__l10n']['one attachment'] = 'Eine Dateianlage';
$GLOBALS['__l10n']['%d attachments'] = '%d Dateianlagen';
$GLOBALS['__l10n']['previous entries'] = 'ältere Einträge';
$GLOBALS['__l10n']['page'] = 'Seite';
$GLOBALS['__l10n']['of'] = 'von';
$GLOBALS['__l10n']['next entries'] = 'neure Einträge';
$GLOBALS['__l10n']['Search'] = 'Suche';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Deine Suche nach <em>%1$s</em> ergab keinen Treffer.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Deine Suche nach <em>%1$s</em> ergab <strong>%2$s</strong> Treffer.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Deine Suche nach <em>%1$s</em> ergab <strong>%2$s</strong> Treffer.';
$GLOBALS['__l10n']['Home'] = 'Startseite';
$GLOBALS['__l10n']['All keywords'] = 'Alle Schlüsselwörter';
$GLOBALS['__l10n']['Best of me'] = 'Das Wichtigste über mich';
$GLOBALS['__l10n']['Languages'] = 'Sprachen';
$GLOBALS['__l10n']['Categories'] = 'Kategorien';
$GLOBALS['__l10n']['Subcategories'] = 'Unterkategorien';
$GLOBALS['__l10n']['Archives'] = 'Archiv';
$GLOBALS['__l10n']['Links'] = 'Links';
$GLOBALS['__l10n']['Subscribe'] = 'Abonnements';
$GLOBALS['__l10n']['Entries feed'] = 'Feed für Einträge';
$GLOBALS['__l10n']['Comments feed'] = 'Feed für Kommentare';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Die Kommentare dieses Blogs als Atom-Feed abonnieren';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Die Einträge dieser Kategorie als Atom-Feed abonnieren';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Die Kommentare dieser Kategorie als Atom-Feed abonnieren';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Die Kommentare dieses Eintrags als Atom-Feed abonnieren';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Die Kommentare dieses Eintrags als Atom-Feed abonnieren';
$GLOBALS['__l10n']['Attachments'] = 'Dateianlagen';
$GLOBALS['__l10n']['Permalink'] = 'Permalink';
$GLOBALS['__l10n']['Comments'] = 'Kommentare';
$GLOBALS['__l10n']['Your comment'] = 'Dein Kommentar';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Dein Kommentar wurde erfolgreich veröffentlicht.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Dein Kommentar wurde gespeichert und wird nach Überprüfung veröffentlicht.';
$GLOBALS['__l10n']['Add a comment'] = 'Kommentar eintragen';
$GLOBALS['__l10n']['Name or nickname'] = 'Name oder Nickname';
$GLOBALS['__l10n']['Email address'] = 'E-Mail-Adresse';
$GLOBALS['__l10n']['Website'] = 'Website';
$GLOBALS['__l10n']['optional'] = 'freiwillig';
$GLOBALS['__l10n']['Comment'] = 'Kommentar';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = 'Kommentare können mit einfacher Wiki-Syntax formatiert werden.';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML-Code wird als normaler Text angezeigt, Links und Email-Adressen werden automatisch umgewandelt.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Speichere meine Angaben für diesen Blog';
$GLOBALS['__l10n']['preview'] = 'Vorschau';
$GLOBALS['__l10n']['send'] = 'Senden';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Folgende haben zum gleichen Thema veröffentlicht';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback-URL';
$GLOBALS['__l10n']['You must provide an author name'] = 'Du musst einen Namen oder Nicknamen angeben';
$GLOBALS['__l10n']['You must provide a comment'] = 'Du musst einen Kommentar eingeben';
$GLOBALS['__l10n']['Email address is not valid'] = 'Die E-Mail-Adresse ist nicht gültig';
$GLOBALS['__l10n']['Document not found'] = 'Dokument nicht gefunden';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Das gesuchte Dokument existiert nicht.';
$GLOBALS['__l10n']['Powered by %s'] = 'Erstellt mit %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Abonnieren von';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Was ist ein RSS-Feed?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '<abbr xml:lang="en" lang="en" title="Really Simple Syndication">RSS</abbr> ist eine kostenlose Inhaltsübersicht für den Blog. Man kann Inhalte (z.B. Einträge oder Kommentare) oder auch Auszüge von Inhalten mit Links und anderen Metadaten abonnieren. Diese kannst du dann in einem beliebigen <a href="http://de.wikipedia.org/wiki/Feedreader">Feedreader</a>. lesen.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Kopiere einfach den folgenden URL in deinen Feedreader:';
$GLOBALS['__l10n']['Password needed'] = 'Passwort erforderlich';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Für den Zutritt benötigst du ein Passwort.';
$GLOBALS['__l10n']['Password:'] = 'Passwort:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Du mußt eine gültige E-Mail-Adresse verwenden.';
$GLOBALS['__l10n']['Read'] = 'Lesen';
$GLOBALS['__l10n']['By date'] = 'Nach Datum';
$GLOBALS['__l10n']['FromDay'] = 'Von';
$GLOBALS['__l10n']['toDay'] = 'bis';
$GLOBALS['__l10n']['By category'] = 'Nach Kategorien';
$GLOBALS['__l10n']['By tag'] = 'Nach Tags';
